@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: future_fstrings -*-
 
 import os.path
 
@@ -7,4 +7,5 @@ DEFAULT_CONFIG_FILE = os.path.join(DEFAULT_CONFIG_DIR, "config")
 DEFAULT_CREDENTIALS_FILE = os.path.join(DEFAULT_CONFIG_DIR, "credentials")
 DEFAULT_PROFILE = "default"
 DEFAULT_GLOBAL_ENDPOINT = "production"
+DEFAULT_ENDPOINT_MAP_FILE = "endpoint_map.json"
 DEFAULT_RESIDENCY = "default"
